gz-transport
Rust wrapper for Gazebo Transport.
| Gazebo version | Gazebo Transport version |
|---|---|
| Fortress (LTS) | 11 |
| Garden (EOL) | 12 |
| Harmonic (LTS) | 13 |
| Ionic | 14 |
| Jetty (LTS) | 15 |
This crate supports multiple versions of Gazebo Transport. The version is determined by the feature flag or by pkg-config.
If a feature flag (fortress, garden, harmonic, ionic, or jetty) is specified, the corresponding version of the gz-transport library will be linked. Specifying more than one will result in a compile error.
[dependencies]
gz-transport = { version = "0.10.0", features = ["harmonic"] }If no feature flag is specified, the version is determined using pkg-config. When multiple versions are installed, the newest takes precedence. To use an older version, set the feature flag as above.
Structs
- Node
- A struct that allows a client to communicate with other peers
- Publisher
- A publisher of a topic.
To instantiate a publisher, useNode::advertise
Functions
- wait_
for_ shutdown - Block the current thread until a SIGINT or SIGTERM is received.